@@ -552,7 +552,10 @@ prolog_load_context(script, Bool) :-
     ;   Bool = false
     ).
 prolog_load_context(variable_names, Bindings) :-
-    nb_current('$variable_names', Bindings).
+    (   nb_current('$variable_names', Bindings0)
+    ->  Bindings = Bindings0
+    ;   Bindings = []
+    ).
 prolog_load_context(term, Term) :-
     nb_current('$term', Term).
 prolog_load_context(reloading, true) :-
@@ -873,6 +876,8 @@ define_or_generate(Pred) :-
     '$get_predicate_attribute'(Pred, (thread_local), 1).
 '$predicate_property'((multifile), Pred) :-
     '$get_predicate_attribute'(Pred, (multifile), 1).
+'$predicate_property'((discontiguous), Pred) :-
+    '$get_predicate_attribute'(Pred, (discontiguous), 1).
 '$predicate_property'(imported_from(Module), Pred) :-
     '$get_predicate_attribute'(Pred, imported, Module).
 '$predicate_property'(transparent, Pred) :-
