@@ -1095,8 +1095,6 @@ considerAGC(void)
 
 #endif /*O_ATOMGC*/
 
-#undef PL_register_atom
-#undef PL_unregister_atom
 
 void
 resetAtoms()
@@ -1132,8 +1130,8 @@ register_atom(volatile Atom p)
 
 
 void
-PL_register_atom(atom_t a)
-{
+(PL_register_atom)(atom_t a)
+{ 
 #ifdef O_ATOMGC
   size_t index = indexAtom(a);
 
@@ -1259,8 +1257,8 @@ unregister_atom(volatile Atom p)
 
 
 void
-PL_unregister_atom(atom_t a)
-{
+(PL_unregister_atom)(atom_t a)
+{ 
 #ifdef O_ATOMGC
   size_t index = indexAtom(a);
 
@@ -1667,8 +1665,9 @@ cleanupAtoms(void)
 }
 
 
+#define current_blob(a, type, call, state) LDFUNC(current_blob, a, type, call, state)
 static word
-current_blob(term_t a, term_t type, frg_code call, intptr_t state ARG_LD)
+current_blob(DECL_LD term_t a, term_t type, frg_code call, intptr_t state)
 { atom_t type_name = 0;
   size_t index;
   int i, last=0;
@@ -1726,7 +1725,7 @@ current_blob(term_t a, term_t type, frg_code call, intptr_t state ARG_LD)
 	   atom->atom != ATOM_garbage_collected &&
 	   bump_atom_references(atom, refs) )
       { DEBUG(CHK_ATOM_GARBAGE_COLLECTED,
-	      /* avoid trap through linkVal__LD() check */
+	      /* avoid trap through linkVal() check */
 	      if ( atom->atom == ATOM_garbage_collected )
 	      { PL_unregister_atom(atom->atom);
 	        continue;
@@ -1762,7 +1761,7 @@ static
 PRED_IMPL("current_blob", 2, current_blob, PL_FA_NONDETERMINISTIC)
 { PRED_LD
 
-  return current_blob(A1, A2, CTX_CNTRL, CTX_INT PASS_LD);
+  return current_blob(A1, A2, CTX_CNTRL, CTX_INT);
 }
 
 
@@ -1770,7 +1769,7 @@ static
 PRED_IMPL("current_atom", 1, current_atom, PL_FA_NONDETERMINISTIC)
 { PRED_LD
 
-  return current_blob(A1, 0, CTX_CNTRL, CTX_INT PASS_LD);
+  return current_blob(A1, 0, CTX_CNTRL, CTX_INT);
 }
 
 
@@ -2104,7 +2103,7 @@ atom_generator(PL_chars_t *prefix, PL_chars_t *hit, int state)
     for(; index<upto; index++)
     { Atom a = b + index;
 
-      if ( is_signalled(PASS_LD1) )	/* Notably allow windows version */
+      if ( is_signalled() )	/* Notably allow windows version */
       { if ( PL_handle_signals() < 0 )	/* to break out on ^C */
 	  return FALSE;
       }
