@@ -37,6 +37,9 @@
 #ifndef PL_GLOBAL_H_INCLUDED
 #define PL_GLOBAL_H_INCLUDED
 #include "pl-allocpool.h"
+#include "pl-mutex.h"
+#include "pl-thread.h"
+#include "pl-gmp.h"
 
 #ifndef GLOBAL			/* global variables */
 #define GLOBAL extern
@@ -726,6 +729,7 @@ struct PL_local_data
     gen_t	      gen_nest;		/* Start of nested generation */
     gen_t	      generation;	/* Local current generation */
     Table	      clauses;		/* Affected clauses */
+    Table	      predicates;	/* Pred --> last modified */
     struct tbl_trail *table_trail;	/* Affected tables */
     term_t	      id;		/* Default the goal */
     struct tr_stack  *stack;		/* Nested transaction stack */
