@@ -116,6 +116,13 @@
 /* Our definition of _PL_get_arg appears in pl-fli.h */
 #undef _PL_get_arg
 
+/* This is only here to assist static analysis; undefine this and
+ * the LDFUNC functions will look like normal definitions, as though
+ * this were a single-threaded build */
+#define USE_LD_MACROS 1
+#ifdef __INTELLISENSE__
+# undef USE_LD_MACROS
+#endif
 
 /* COMMON() was a macro used to mark symbols to be global to the library
  * internals but not exported from the shared library. This is now the
@@ -1110,8 +1117,6 @@ typedef uint64_t lgen_t;
 	do { (f)->generation = (gen); } while(0)
 #endif
 
-#define setGenerationFrame(fr) setGenerationFrame__LD((fr) PASS_LD)
-
 #define FR_LCO_CLEAR	(FR_SKIPPED|FR_WATCHED|FR_CATCHED|\
 			 FR_HIDE_CHILDS|FR_CLEANUP|FR_SSU_DET)
 #define FR_CLEAR_NEXT	(FR_LCO_CLEAR|FR_DET|FR_DETGUARD)
@@ -1175,7 +1180,7 @@ it mean anything?
 
 #define startCritical (void)(LD->critical++)
 #define endCritical   ((--(LD->critical) == 0 && LD->alerted) \
-				? endCritical__LD(PASS_LD1) : TRUE)
+				? f_endCritical() : TRUE)
 
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 LIST processing macros.
@@ -1326,8 +1331,6 @@ typedef struct functor_table
 	  (cl)->generation.erased   > (gen) \
 	)
 
-#define visibleClause(cl, gen) visibleClause__LD(cl, gen PASS_LD)
-#define visibleClauseCNT(cl, gen) visibleClauseCNT__LD(cl, gen PASS_LD)
 
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Struct clause must be a  multiple   of  sizeof(word)  for compilation on
@@ -2000,7 +2003,6 @@ Note that all trail operations demand that   the caller ensures there is
 at least one free cell on the trail-stack.
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-#define Trail(p, w) Trail__LD(p, w PASS_LD)
 					/* trail local stack pointer */
 #define LTrail(p) \
   (void)((tTop++)->address = p)
@@ -2225,7 +2227,7 @@ typedef enum
 	do { if ( likely(aTop+1 < aMax) ) \
 	       *aTop++ = (p); \
 	     else \
-	       pushArgumentStack__LD((p) PASS_LD); \
+	       f_pushArgumentStack(p); \
 	   } while(0)
 
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -2612,9 +2614,9 @@ with any luck LTO could address that.
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
 #if USE_ALLOC_INLINES
-# define ALLOC_INLINE(type) static type MAYBE_UNUSED
+# define ALLOC_INLINE static MAYBE_UNUSED
 #else
-# define ALLOC_INLINE COMMON
+# define ALLOC_INLINE 
 #endif
 
 #include "pl-alloc.h"			/* Allocation primitives */
@@ -2627,7 +2629,6 @@ with any luck LTO could address that.
 #include "os/pl-locale.h"		/* Locale objects */
 #include "os/pl-file.h"			/* Stream management */
 #include "pl-global.h"			/* global data */
-#include "pl-ldpass.h"			/* Wrap __LD functions */
 #include "pl-inline.h"			/* Inline facilities */
 #include "pl-privitf.h"			/* private foreign interface */
 #include "os/pl-text.h"			/* text manipulation */
