@@ -79,8 +79,9 @@ allocBuffer(Buffer b, size_t size)
 }
 
 
+#define primitiveHashValue(term, hval) LDFUNC(primitiveHashValue, term, hval)
 static int
-primitiveHashValue(word term, unsigned int *hval ARG_LD)
+primitiveHashValue(DECL_LD word term, unsigned int *hval)
 { switch(tag(term))
   { case TAG_VAR:
     case TAG_ATTVAR:
@@ -123,8 +124,9 @@ primitiveHashValue(word term, unsigned int *hval ARG_LD)
 }
 
 
+#define start_term(work, b, w) LDFUNC(start_term, work, b, w)
 static void
-start_term(th_data *work, Buffer b, word w ARG_LD)
+start_term(DECL_LD th_data *work, Buffer b, word w)
 { atom_t name;
 
   work->term     = valueTerm(w);
@@ -155,8 +157,9 @@ This is not enough.  Consider:
 Making every parent a cycle works, but might loose a bit too much :-(
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
+#define next_arg(workp, b) LDFUNC(next_arg, workp, b)
 static Word
-next_arg(th_data **workp, Buffer b ARG_LD)
+next_arg(DECL_LD th_data **workp, Buffer b)
 { th_data *work = *workp;
 
   for(;;)
@@ -214,12 +217,13 @@ update_cycle(th_data *here, th_data *start, Buffer b)
 }
 
 
+#define termHashValue(p, hval) LDFUNC(termHashValue, p, hval)
 static int
-termHashValue(Word p, unsigned int *hval ARG_LD)
+termHashValue(DECL_LD Word p, unsigned int *hval)
 { deRef(p);
   if ( !isTerm(*p) )
   { *hval = MURMUR_SEED;
-    return primitiveHashValue(*p, hval PASS_LD);
+    return primitiveHashValue(*p, hval);
   } else
   { tmp_buffer tmp;
     Buffer b = (Buffer)&tmp;
@@ -229,13 +233,13 @@ termHashValue(Word p, unsigned int *hval ARG_LD)
 
     initBuffer(&tmp);
     work = allocBuffer(b, sizeof(*work));	/* cannot fail */
-    start_term(work, b, *p PASS_LD);
+    start_term(work, b, *p);
     work->parent_offset = (size_t)-1;
     t->definition = consInt(0);
 
-    while ( (p = next_arg(&work, b PASS_LD)) )
+    while ( (p = next_arg(&work, b)) )
     { if ( !isTerm(*p) )
-      { if ( primitiveHashValue(*p, &work->hash PASS_LD) )
+      { if ( primitiveHashValue(*p, &work->hash) )
 	{ work->arg++;
 	} else
 	{ rc = FALSE;
@@ -268,7 +272,7 @@ termHashValue(Word p, unsigned int *hval ARG_LD)
 	  { rc = -1;			/* out of memory */
 	    goto out;
 	  }
-	  start_term(work, b, *p PASS_LD);
+	  start_term(work, b, *p);
 	  work->parent_offset = parent;
 	  t->definition = consInt(nodeID(work, b));
 	}
@@ -306,7 +310,7 @@ PRED_IMPL("term_hash", 2, term_hash, 0)
   unsigned int hraw;
   int rc;
 
-  rc = termHashValue(p, &hraw PASS_LD);
+  rc = termHashValue(p, &hraw);
 
   if ( rc )
   { hraw = hraw & PLMAXTAGGEDINT32;	/* ensure tagged (portable) */
@@ -441,8 +445,9 @@ push_attvar(Word p, sha1_state *state)
 	    hash_compile(state->ctx.murmur, (const unsigned char*)(p), (l)); \
 	} while(0)
 
+#define variant_sha1(agenda, state) LDFUNC(variant_sha1, agenda, state)
 static status
-variant_sha1(ac_term_agenda *agenda, sha1_state *state ARG_LD)
+variant_sha1(DECL_LD ac_term_agenda *agenda, sha1_state *state)
 { Word p;
 
   while( (p=ac_nextTermAgenda(agenda)) )
@@ -543,8 +548,9 @@ variant_sha1(ac_term_agenda *agenda, sha1_state *state ARG_LD)
 }
 
 
+#define variant_hash(term, hash, algorithm) LDFUNC(variant_hash, term, hash, algorithm)
 static int
-variant_hash(term_t term, term_t hash, hash_algo algorithm ARG_LD)
+variant_hash(DECL_LD term_t term, term_t hash, hash_algo algorithm)
 { int rc;
   ac_term_agenda agenda;
   sha1_state state;
@@ -560,7 +566,7 @@ variant_hash(term_t term, term_t hash, hash_algo algorithm ARG_LD)
   ac_initTermAgenda(&agenda, valTermRef(term));
   initSegStack(&state.vars, sizeof(Word),
 	       sizeof(state.vars_first_chunk), state.vars_first_chunk);
-  rc = variant_sha1(&agenda, &state PASS_LD);
+  rc = variant_sha1(&agenda, &state);
   ac_clearTermAgenda(&agenda);
   while(popSegStack(&state.vars, &p, Word))
   { word w = (word)p;
@@ -619,13 +625,13 @@ basically execute numbervars.
 static
 PRED_IMPL("variant_sha1", 2, variant_sha1, 0)
 { PRED_LD
-  return variant_hash(A1, A2, HASH_SHA1 PASS_LD);
+  return variant_hash(A1, A2, HASH_SHA1);
 }
 
 static
 PRED_IMPL("variant_hash", 2, variant_hash, 0)
 { PRED_LD
-  return variant_hash(A1, A2, HASH_MURMUR PASS_LD);
+  return variant_hash(A1, A2, HASH_MURMUR);
 }
 
 		 /*******************************
